import QtQuick 1.1
import qb.components 1.0
import BasicUIControls 1.0;

StyledRectangle {
	id: root
	width: 122
	height: 86

	property string kpiPostfix: subLabelText
	property alias subLabelText: subLabel.text
	property int stateId: -1
	property real temperature: 0
	property bool selected: false
	radius: 6
	topLeftRadiusRatio: 0
	topRightRadiusRatio: 0
	bottomLeftRadiusRatio: 0
	bottomRightRadiusRatio: 0
	borderWidth: 1
	borderColor: colors.tempTileBorderUp
	borderStyle: Qt.SolidLine

	mouseIsActiveInDimState: true

	shadowColor: colors.shadow

	onTemperatureChanged: {
		label.text = i18n.number(temperature, 1) + "°";
	}

	Item {
		id: fakeTopBaseline
		height: 40
		anchors.top: parent.top
	}

	Text {
		id: label
		anchors.baseline: fakeTopBaseline.bottom
		anchors.horizontalCenter: parent.horizontalCenter
		font.family: qfont.semiBold.name
		font.pixelSize: 20
	}

	Item {
		id: fakeBottomBaseline
		height: 26
		anchors.bottom: parent.bottom
	}

	Text {
		id: subLabel
		anchors.baseline: fakeBottomBaseline.top
		anchors.horizontalCenter: parent.horizontalCenter
		font.family: qfont.regular.name
		font.pixelSize: 15
	}

	state: "up"

	states: [
		State {
			name: "up"
			PropertyChanges { target: root;     color: colors.tempTileBackgroundUp }
			PropertyChanges { target: root;     shadowPixelSize: 1 }
			PropertyChanges { target: root;     borderColor: colors.tempTileBorderUp }
			PropertyChanges { target: label;    color: colors.tempTileTextUp }
			PropertyChanges { target: subLabel; color: colors.tempTileTextUp }
		},
		State {
			name: "down"
			PropertyChanges { target: root;     color: colors.tempTileBackgroundDown }
			PropertyChanges { target: root;     shadowPixelSize: 0 }
			PropertyChanges { target: root;     borderColor: colors.tempTileBorderDown }
			PropertyChanges { target: label;    color: colors.tempTileTextDown }
			PropertyChanges { target: subLabel; color: colors.tempTileTextDown }
		},
		State {
			name: "unselected"
			PropertyChanges { target: root;     color: colors.tempTileBackgroundUp }
			PropertyChanges { target: root;     shadowPixelSize: 1 }
			PropertyChanges { target: root;     borderColor: colors.tempTileBorderUp }
			PropertyChanges { target: label;    color: colors.tempTileTextUp }
			PropertyChanges { target: subLabel; color: colors.tempTileTextUp }
		},
		State {
			name: "selected"
			PropertyChanges { target: root;     color: colors.tempTileBackgroundDown }
			PropertyChanges { target: root;     shadowPixelSize: 0 }
			PropertyChanges { target: root;     borderColor: colors.tempTileBorderDown }
			PropertyChanges { target: label;    color: colors.tempTileTextDown }
			PropertyChanges { target: subLabel; color: colors.tempTileTextDown }
		},
		State {
			name: "disabled"
		}
	]

	onSelectedChanged: {
		if (selected) {
			root.state = "selected"
		} else {
			root.state = "unselected"
		}
	}
}
